# 组件概述
## 组件定义
* 面向产品配置人员提供灵活的应用配置、测试、发布的工具、流程支持。提供组件的配置组装。
## 组件价值
* 1. 为支撑公司各项业务，提供快速复用已有的组件、灵活组装的技术能力；
* 2. 为工程院移动开发提供组件化开发框架；
* 3. 提供移动组件的开发、测试、发布过程中的工具化、自动化工具的支持；
* 4. 解决组件化开发后组装应用开发、运行过程中要解决的公共技术问题；
* 面向产品配置人员提供灵活的应用配置、测试、发布的工具、流程支持。
## 端支持
* 服务端API
# 设计文档&使用指南
* 设计文档作为一个索引，记录已开发的特性、设计文档、使用指南
* [设计文档](docs/design.md)
* [使用指南](https://reference.doc.101.com/appfactory/userguide/#/)
# API信息
* [API](https://api.e.101.com/services/app-native-storage/description/rest)
# 测试报告
* [功能测试报告](https://pms.sdp.101.com/#/track/testPlan/report/detail/5f0026b9-f144-42d8-81d1-04f8c8cd6d36)
# 代码质量
* [sonarqube报告](http://sonar.sdp.nd/dashboard?id=app-native-storage)，包含单测覆盖率和静态代码检查
![img](docs/imgs/sonar.png)